;----------------------------------------------------------------------------------------
; Title:    MediaPortal Resolution Supervisor
; Version:  1.1
; Date:     09.08.2010
; Author:   ZuNixNuZ
; History:
;	V1.0: - Initial release
;	V1.1: - Waiting for MediaPortal after resolution is correct changed
;			from 10sec to 30sec
;		  - Delay inserted (default 10sec) before sending ALT+ENTER
;		  - Added missing brackets around if expressions
;	V1.2: - If expressions for command line options changed
;		  - Default delay changed from 10sec to 20sec
;	V1.3: - System performance reduced
;
; Script functionalities:
;	If a wrong resolution is detected...
;		- MediaPortal will be closed and started again (C_MEDIAPORTAL_RESTART=1) or
;		- twice ALT+ENTER will be sendet to MediaPortal (C_MEDIAPORTAL_RESTART=0)
;	...if the correct resolution (Default: 1920x1080) is available.
;	Command line options:
;	"ResolutionSupervisor.exe 1680 1050 7"
;	will set correct resolution to 1680x1050 and the delay for sending ALT+ENTER
;	after detecting the correct resolution to 7 sec.
;	If no command line options are given the default resolutions (1920x1080) and
;	delay (20 sec) will be used.
;
;----------------------------------------------------------------------------------------


;----------------------------------------------------------------------------------------
; AutoHotkey recommend default settings

#NoEnv	; Recommended for performance and compatibility with future AutoHotkey releases.
SendMode Input	; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%	; Ensures a consistent starting directory.

;----------------------------------------------------------------------------------------
; Config section

C_MediaPortal_exe = %A_ProgramFiles%\Team MediaPortal\MediaPortal\MediaPortal.exe

C_SCREENWIDTH_OK = 1920
C_SCREENHEIGHT_OK = 1080
C_RESOLUTION_OK_DELAY = 20000

C_MEDIAPORTAL_RESTART = 0

SetTitleMatchMode 2		; A window's title can contain WinTitle anywhere inside it to be a match.

;----------------------------------------------------------------------------------------
; Main

; Initialisation
if ( %0% < 2)
{
	V_SreenwidthOk = %C_SCREENWIDTH_OK%
	V_ScreenheightOk = %C_SCREENHEIGHT_OK%
}
else
{
	V_SreenwidthOk = %1%
	V_ScreenheightOk = %2%
}
if ( %0% > 2)
{
	V_ResolutionOkDelay = %3%
}
else
{
	V_ResolutionOkDelay = %C_RESOLUTION_OK_DELAY%
}
V_ResolutionNok = 0
V_ResolutionOkCnt = 0
V_ResolutionNokCnt = 0

Loop
{
	menu TRAY, Tip, ResolutionSupervisor %V_SreenwidthOk% x %V_ScreenheightOk% info:`n OK delay: %V_ResolutionOkDelay% sec`n NOK counter: %V_ResolutionNokCnt%`n OK counter: %V_ResolutionOkCnt%

	if (V_ResolutionNok == 0)
	{
		; Check if wrong resolution is set
		if ((A_ScreenWidth != V_SreenwidthOk) || (A_ScreenHeight != V_ScreenheightOk))
		{
			; Wrong resolution detected!
			V_ResolutionNokCnt++
			gosub F_ResolutionNok		; Sub-function for resolution changed to "wrong"
			V_ResolutionNok:= 1
		}
	}
	else
	{
		; Check if correct resolution is set
		if ((A_ScreenWidth == V_SreenwidthOk) && (A_ScreenHeight == V_ScreenheightOk))
		{
			; Correct resolution detected!
			V_ResolutionOkCnt++
			gosub F_ResolutionOk		; Sub-function for resoltuion changed to "correct"
			V_ResolutionNok:= 0
		}
	}
	Sleep 1500
}

return

;----------------------------------------------------------------------------------------
; Resolution wrong

F_ResolutionNok:

	IfWinExist MediaPortal
	{
		WinActivate MediaPortal
		if (C_MEDIAPORTAL_RESTART == 1)
		{
			WinWaitClose MediaPortal
		}
	}
	
return

;----------------------------------------------------------------------------------------
; Resolution correct

F_ResolutionOk:

	if (C_MEDIAPORTAL_RESTART == 1)
	{
		IfWinNotExist MediaPortal
		{
			IfExist %C_MediaPortal_exe%
			{
				Run %C_MediaPortal_exe%
				WinWait MediaPortal , , 20
			}
			else
			{
				MsgBox ERROR: MediaPortal not found!
				ExitApp
			}
		}
	}
	
	WinActivate MediaPortal
	WinWaitActive MediaPortal , , 30	; wait until MediaPortal is active (timeout 30sec)
	
	;WinGetActiveStats V_MpTitle, V_MpWidth, V_MpHeight, V_MpX, V_MpY 
	;MsgBox The active window "%V_MpTitle%" is %V_MpWidth% wide`, %V_MpHeight% tall`, and positioned at %V_MpX%`,%V_MpY%

	if (C_MEDIAPORTAL_RESTART == 0)
	{
		Sleep V_ResolutionOkDelay		; wait
        SendInput {Blind}!{Enter}
        Sleep 3000
        SendInput {Blind}!{Enter}
	}
	
return
